==> mule-runtime-extension-model-4.4.0-20221024-test-sources.jar: org/mule/runtime/config/internal/validation/SetVariableVariableNameValidationTestCase.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.validation;

import static org.mule.test.allure.AllureConstants.MuleDsl.DslValidationStory.DSL_VALIDATION_STORY;
import static org.mule.test.allure.AllureConstants.MuleDsl.MULE_DSL;

import static java.util.Optional.empty;

import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;

import org.mule.runtime.ast.api.validation.Validation;
import org.mule.runtime.ast.api.validation.ValidationResultItem;

import java.util.Optional;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;
import org.junit.Test;

@Feature(MULE_DSL)
@Story(DSL_VALIDATION_STORY)
@Issue("W-10998630")
public class SetVariableVariableNameValidationTestCase extends AbstractCoreValidationTestCase {

  @Override
  protected Validation getValidation() {
    return new NoExpressionsInNoExpressionsSupportedParams();
  }

  @Test
  public void variableNameSupportsExpressionsSoNoValidationShouldArise() {
    final Optional<ValidationResultItem> msg = runValidation("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
        "<mule xmlns=\"http://www.mulesoft.org/schema/mule/core\" xmlns:doc=\"http://www.mulesoft.org/schema/mule/documentation\"\n"
        +
        "   xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
        "   xsi:schemaLocation=\"http://www.mulesoft.org/schema/mule/core http://www.mulesoft.org/schema/mule/core/current/mule.xsd\">\n"
        +
        "   <flow name=\"expression-for-variablenameFlow\">\n" +
        "       <set-variable value=\"myVariable\" variableName=\"targetName\"/>" +
        "       <set-variable value=\"specialValue\" variableName=\"#[vars.targetName]\"/>\n" +
        "   </flow>\n" +
        "</mule>");

    assertThat(msg, is(empty()));
  }
}

==> mule-runtime-extension-model-4.5.0-20221117-test-sources.jar: org/mule/runtime/config/internal/validation/SetVariableVariableNameValidationTestCase.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.validation;

import static org.mule.test.allure.AllureConstants.MuleDsl.DslValidationStory.DSL_VALIDATION_STORY;
import static org.mule.test.allure.AllureConstants.MuleDsl.MULE_DSL;

import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;

import org.mule.runtime.ast.api.validation.Validation;
import org.mule.runtime.ast.api.validation.ValidationResultItem;

import java.util.Optional;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;
import org.junit.Test;

@Feature(MULE_DSL)
@Story(DSL_VALIDATION_STORY)
@Issue("W-10998630")
public class SetVariableVariableNameValidationTestCase extends AbstractCoreValidationTestCase {

  @Override
  protected Validation getValidation() {
    return new NoExpressionsInNoExpressionsSupportedParams();
  }

  @Test
  public void variableNameSupportsExpressionsSoNoValidationShouldArise() {
    final Optional<ValidationResultItem> msg = runValidation("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
        "<mule xmlns=\"http://www.mulesoft.org/schema/mule/core\" xmlns:doc=\"http://www.mulesoft.org/schema/mule/documentation\"\n"
        +
        "   xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
        "   xsi:schemaLocation=\"http://www.mulesoft.org/schema/mule/core http://www.mulesoft.org/schema/mule/core/current/mule.xsd\">\n"
        +
        "   <flow name=\"expression-for-variablenameFlow\">\n" +
        "       <set-variable value=\"myVariable\" variableName=\"targetName\"/>" +
        "       <set-variable value=\"specialValue\" variableName=\"#[vars.targetName]\"/>\n" +
        "   </flow>\n" +
        "</mule>")
            .stream().findFirst();

    assertThat(msg.isPresent(), is(false));
  }
}
